@@ -50,12 +50,12 @@ KNOWN_FILES = [
     "hooks/pre-rebase",
     "info/exclude",
     "logs/HEAD",
-    "logs/refs/heads/master",
+    "logs/refs/heads/{{branch}}",
     "logs/refs/remotes/origin/HEAD",
-    "logs/refs/remotes/origin/master",
-    "refs/heads/master",
+    "logs/refs/remotes/origin/{{branch}}",
+    "refs/heads/{{branch}}",
     "refs/remotes/origin/HEAD",
-    "refs/remotes/origin/master",
+    "refs/remotes/origin/{{branch}}",
 ]
 
 
@@ -87,13 +87,34 @@ class GitRecoveryBot(HTTPBot):
             f = os.path.join(".git", f)
             if not os.path.exists(f):
                 os.makedirs(f)
-        # retrieve existing .git files and commits
-        self.__fetch_files()
-        self.__fetch_commits()
+    
+    def __checkout_branch(self, branch):
+        """
+        Checkout the given branch.
+        
+        :param branch: branch name
+        """
+        cmd = "git checkout {}".format(branch)
+        self.logger.debug("Trying '{}'".format(cmd))
+        out, err = execute(cmd)
+        if b("error:") in err or b("fatal:") in err:
+            self.__extract_commits(out, err)
+            self.__last_cmd = cmd
+            self.__checkout_branch(branch)
+        else:
+            for l in out.split(b('\n')):
+                if len(l) > 0 and not l.startswith(b("Already on")):
+                    fp = ensure_str(l).split('\t')[-1]
+                    if fp not in self.files:
+                        self.files.append(fp)
+            for fp in self.files:
+                self.__recover_source(self.__get_revision(fp), fp)
+            self.logger.info("Checkout:\n" + ensure_str(out))
+
     
     def __extract_commits(self, *outputs):
         """
-        Method for extracting commits from a given output.
+        Extract commits from a given output.
 
         :param outputs: output texts, e.g. the content of .git/logs/HEAD
         :return:        list of found hashes
@@ -108,7 +129,7 @@ class GitRecoveryBot(HTTPBot):
     
     def __fetch_file(self, fp, commit=False, skip=True):
         """
-        Method for fetching .git files.
+        Fetch .git files.
 
         :param fp:     file path (without prepended ".git")
         :param commit: whether the file is a commit or not
@@ -120,13 +141,13 @@ class GitRecoveryBot(HTTPBot):
             sha1 = fp
             fp = "objects/{}/{}".format(fp[:2], fp[2:])
         dest = os.path.join(".git/", fp)
+        if skip and os.path.exists(dest):
+            self.logger.debug("{} skipped".format(fp))
+            return
         if commit:
             self.logger.debug("Fetching commit {}".format(sha1))
         else:
             self.logger.debug("Fetching file {}".format(fp))
-        if skip and os.path.exists(dest):
-            self.logger.debug("{} skipped".format(fp))
-            return
         # check if the file exists with a HEAD request
         reqp = self._parsed.path + "/.git/" + fp
         self.head(reqp)
@@ -149,9 +170,9 @@ class GitRecoveryBot(HTTPBot):
         elif self.response.status_code == 403:
             self.logger.warning(fp)
     
-    def __fetch_commits(self):
+    def __fetch_commits(self, branch):
         """
-        Method for fetching commits from known files.
+        Fetching commits from known files.
         """
         try:
             with open(".git/logs/HEAD") as f:
@@ -159,16 +180,17 @@ class GitRecoveryBot(HTTPBot):
         except IOError:
             self.logger.warning("Could not extract commits from logs/HEAD")
         try:
-            with open(".git/refs/heads/master") as f:
+            with open(".git/refs/heads/%s" % branch) as f:
                 self.__fetch_file(f.read().strip(), True)
         except IOError:
-            self.logger.warning("Could not extract commits from refs/heads/master")
+            self.logger.warning("Could not extract commits from refs/heads/%s" % branch)
     
-    def __fetch_files(self):
+    def __fetch_files(self, branch):
         """
-        Bulk method for fetching known files.
+        Fetch known files.
         """
         for fp in KNOWN_FILES:
+            fp = fp.replace("{{branch}}", branch)
             if not os.path.exists(os.path.join(".git/", fp)):
                 self.__fetch_file(fp)
     
@@ -205,28 +227,27 @@ class GitRecoveryBot(HTTPBot):
             self.__recover_source(sha1, fp)
         else:
             self.logger.info("Successfully recovered {}".format(fp))
-
-    def checkout(self, branch="master"):
+    
+    def __valid_branch(self, branch):
+        """
+        Validate if a given branch name exists.
+        
+        :param branch: branch name
+        """
+        self.head(self._parsed.path + "/.git/refs/heads/" + branch)
+        return self.response.status_code == 200
+    
+    def checkout(self, branch="main"):
         """
         Git respository file enumeration function.
 
         :param branch: repository branch to be enumerated
         """
-        if not self.__git_installed:
+        if not self.__git_installed or not self.__valid_branch(branch):
             return
-        cmd = "git checkout {}".format(branch)
-        self.logger.debug("Trying '{}'".format(cmd))
-        out, err = execute(cmd)
-        if b("error:") in err or b("fatal:") in err:
-            self.__extract_commits(out, err)
-            self.checkout(branch)
-        else:
-            for l in out.split(b('\n')):
-                if len(l) > 0 and not l.startswith(b("Already on")):
-                    fp = ensure_str(l).split('\t')[-1]
-                    if fp not in self.files:
-                        self.files.append(fp)
-            for fp in self.files:
-                self.__recover_source(self.__get_revision(fp), fp)
-            self.logger.info("Checkout:\n" + ensure_str(out))
+        # retrieve existing .git files and commits
+        self.__fetch_files(branch)
+        self.__fetch_commits(branch)
+        # now try to checkout and recursively download files
+        self.__checkout_branch(branch)
 
